views.py — django-open-humans documentation

# views.py

class `openhumans.views.` `DeleteAllFiles`(**kwargs)
  `post`(request)

    Delete all project files in Open Humans for this project member.

class `openhumans.views.` `DeleteFile`(**kwargs)
  `post`(request)

    Delete specified file in Open Humans for this project member.

`openhumans.views.` `complete`(request)

  Receive user from Open Humans. Store data, start data upload task.

`openhumans.views.` `deauth`(request)

  Receive and act on deauthorization notification from Open Humans.

class `openhumans.views.` `list_files`(**kwargs)
  `get`(request)

    List files.